==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/OpenShiftControllerManagerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.OpenShiftControllerManagerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManager;
import io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class OpenShiftControllerManagerHandler implements ResourceHandler<OpenShiftControllerManager, OpenShiftControllerManagerBuilder> {

  @Override
  public String getKind() {
    return OpenShiftControllerManager.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public OpenShiftControllerManager create(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public OpenShiftControllerManager replace(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public OpenShiftControllerManager reload(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public OpenShiftControllerManagerBuilder edit(OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, Watcher<OpenShiftControllerManager> watcher) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, String resourceVersion, Watcher<OpenShiftControllerManager> watcher) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, ListOptions options, Watcher<OpenShiftControllerManager> watcher) {
  return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public OpenShiftControllerManager waitUntilReady(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public OpenShiftControllerManager waitUntilCondition(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, Predicate<OpenShiftControllerManager> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.1-sources.jar: io/fabric8/openshift/client/handlers/OpenShiftControllerManagerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.OpenShiftControllerManagerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManager;
import io.fabric8.openshift.api.model.operator.v1.OpenShiftControllerManagerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class OpenShiftControllerManagerHandler implements ResourceHandler<OpenShiftControllerManager, OpenShiftControllerManagerBuilder> {

  @Override
  public String getKind() {
    return OpenShiftControllerManager.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public OpenShiftControllerManager create(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, boolean dryRun) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public OpenShiftControllerManager replace(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, boolean dryRun) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public OpenShiftControllerManager reload(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public OpenShiftControllerManagerBuilder edit(OpenShiftControllerManager item) {
    return new OpenShiftControllerManagerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, OpenShiftControllerManager item, boolean dryRun) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, Watcher<OpenShiftControllerManager> watcher) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, String resourceVersion, Watcher<OpenShiftControllerManager> watcher) {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, ListOptions options, Watcher<OpenShiftControllerManager> watcher) {
  return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public OpenShiftControllerManager waitUntilReady(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public OpenShiftControllerManager waitUntilCondition(OkHttpClient client, Config config, String namespace, OpenShiftControllerManager item, Predicate<OpenShiftControllerManager> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new OpenShiftControllerManagerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
